summaryrefslogtreecommitdiff
path: root/src/mesa/drivers/dri/intel/intel_mipmap_tree.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mesa/drivers/dri/intel/intel_mipmap_tree.h')
-rw-r--r--src/mesa/drivers/dri/intel/intel_mipmap_tree.h25
1 files changed, 15 insertions, 10 deletions
diff --git a/src/mesa/drivers/dri/intel/intel_mipmap_tree.h b/src/mesa/drivers/dri/intel/intel_mipmap_tree.h
index 1a415fbce34..3a465da6e14 100644
--- a/src/mesa/drivers/dri/intel/intel_mipmap_tree.h
+++ b/src/mesa/drivers/dri/intel/intel_mipmap_tree.h
@@ -199,4 +199,4 @@ struct intel_mipmap_tree
*
* For ETC1 textures, this is MESA_FORMAT_RGBX8888_REV if the hardware
* lacks support for ETC1. See @ref wraps_etc1.
*/
@@ -204,2 +204,5 @@ struct intel_mipmap_tree
+ /** This variable stores the value of ETC compressed texture format */
+ gl_format etc_format;
+
/**
@@ -353,12 +356,14 @@ struct intel_mipmap_tree
/**
- * \brief The miptree contains RGBX data that was originally ETC1 data.
+ * \brief The miptree contains uncompressed data that was originally
+ * ETC1/ETC2 data.
*
* On hardware that lacks support for ETC1 textures, we do the
* following on calls to glCompressedTexImage2D(GL_ETC1_RGB8_OES):
* 1. Create a miptree whose format is MESA_FORMAT_RGBX8888_REV with
* the wraps_etc1 flag set.
* 2. Translate the ETC1 data into RGBX.
* 3. Store the RGBX data into the miptree and discard the ETC1 data.
*/
- bool wraps_etc1;
+ bool wraps_etc;
@@ -199,4 +199,4 @@ struct intel_mipmap_tree
*
- * For ETC1 textures, this is MESA_FORMAT_RGBX8888_REV if the hardware
- * lacks support for ETC1. See @ref wraps_etc1.
+ * For ETC1/ETC2 textures, this is one of the uncompressed mesa texture
+ * formats if the hardware lacks support for ETC1/ETC2. See @ref wraps_etc.
*/
@@ -353,12 +356,14 @@ struct intel_mipmap_tree
*
- * On hardware that lacks support for ETC1 textures, we do the
- * following on calls to glCompressedTexImage2D(GL_ETC1_RGB8_OES):
- * 1. Create a miptree whose format is MESA_FORMAT_RGBX8888_REV with
- * the wraps_etc1 flag set.
- * 2. Translate the ETC1 data into RGBX.
- * 3. Store the RGBX data into the miptree and discard the ETC1 data.
+ * On hardware that lacks support for ETC1/ETC2 textures, we do the following
+ * on calls to glCompressedTexImage2D() with an ETC1/ETC2 texture format:
+ * 1. Create a miptree whose format is a suitable uncompressed mesa format
+ * with the wraps_etc flag set.
+ * 2. Translate the ETC1/ETC2 data into uncompressed mesa format.
+ * 3. Store the uncompressed data into the miptree and discard the ETC1/ETC2
+ * data.
*/